@@ -132,7 +132,7 @@ def get_imports(func: Callable) -> Tuple[str, Set[str]]:
                 import_line = f"import {j.__name__} as {i}\n"
 
             if j.__name__ in ["covalent", "lattice", "electron"]:
-                import_line = "# " + import_line
+                import_line = f"# {import_line}"
                 cova_imports.add(i)
 
             imports_str += import_line
@@ -175,15 +175,11 @@ def get_named_params(func, args, kwargs):
                 named_kwargs[param_name] = kwargs[param_name]
             elif ind < len(args):
                 named_args[param_name] = args[ind]
-            elif param.default != param.empty:
-                named_args[param_name] = param.default
         elif param.kind == param.VAR_POSITIONAL:
             for i in range(ind, len(args)):
                 named_args[f"arg[{i}]"] = args[i]
 
         elif param.kind in [param.KEYWORD_ONLY, param.VAR_KEYWORD]:
-            if param.default != param.empty:
-                named_kwargs[param_name] = param.default
             for key, value in kwargs.items():
                 if key != param_name:
                     named_kwargs[key] = value
